<?php

namespace NegarshopElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

class Elementor_header_basket_Widget extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'negarshop_header_basket';
    }

    public function get_title()
    {
        return 'سبد خرید';
    }

    public function get_icon()
    {
        return 'eicon-cart';
    }

    public function get_categories()
    {
        return ['Negarshop_header'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section(
            'settings_section',
            [
                'label' => 'تنظیمات',
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'color_t',
            [
                'label' => 'رنگ',
                'type' => Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default' => 'پیشفرض قالب',
                    'custom' => 'دستی',
                ],
            ]
        );
        $this->add_control(
            'color_1',
            [
                'label' => 'رنگ زمینه گزینه سبد خرید',
                'type' => Controls_Manager::COLOR,
                'default' => '#00bfd6',
                'selectors' => [
                    '{{WRAPPER}} .header-cart-basket .cart-basket-box::before' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-2 .cart-basket-box' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-5 .cart-basket-box > .icon' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'color_t' => 'custom',
                ],
            ]
        );
        $this->add_control(
            'color_2',
            [
                'label' => 'رنگ متن گزینه سبد خرید',
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .header-cart-basket .cart-basket-box' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-2 .cart-basket-box' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-5 .cart-basket-box .title' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-5 .cart-basket-box .count' => 'box-shadow: {{VALUE}} 0 3px 6px',
                ],
                'condition' => [
                    'color_t' => 'custom',
                ],
            ]
        );
        $this->add_control(
            'color_4',
            [
                'label' => 'رنگ زمینه شمارشگر سبد خرید',
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .header-cart-basket .cart-basket-box  span.count' => 'background-color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-2 .cart-basket-box  span.count' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'color_t' => 'custom',
                ],
            ]
        );
        $this->add_control(
            'color_3',
            [
                'label' => 'رنگ متن شمارشگر سبد خرید',
                'type' => Controls_Manager::COLOR,
                'default' => '#00bfd6',
                'selectors' => [
                    '{{WRAPPER}} .header-cart-basket .cart-basket-box  span.count' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-2 .cart-basket-box  span.count' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .header-cart-basket.style-5 .cart-basket-box .count' => 'color: {{VALUE}} !important',
                ],
                'condition' => [
                    'color_t' => 'custom',
                ],
            ]
        );

        $this->add_control(
            'style',
            [
                'label' => 'طرح',
                'type' => Controls_Manager::SELECT,
                'default' => 'style-1',
                'options' => [
                    'style-1' => 'طرح اول',
                    'style-2' => 'طرح دوم',
                    'style-3' => 'طرح سوم',
                    'style-2 style-4' => 'طرح چهارم',
                    'style-5' => 'طرح پنجم',
                ],
            ]
        );

        $this->add_control(
            'bs_align',
            [
                'label' => 'جهت نمایش موارد سبد خرید',
                'type' => Controls_Manager::SELECT,
                'default' => 'right',
                'options' => [
                    'right' => 'به راست',
                    'left' => 'به چپ',
                ],
            ]
        );

        $this->end_controls_section();
        $this->start_controls_section(
            'styles_section',
            [
                'label' => 'استایل ها',
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control('basket_height', [
            'label' => 'عرض سبد خرید',
            'type' => \Elementor\Controls_Manager::SLIDER,
            'default' => [
                'unit' => 'px',
            ],
            'size_units' => ['px', '%'],
            'range' => [
                'px' => [
                    'min' => 1,
                    'max' => 500,
                ],
                '%' => [
                    'min' => 1,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .header-cart-basket .cart-basket-box' => 'height: {{SIZE}}{{UNIT}} !important;'
            ],
        ]);

        $this->add_control(
            'basket_padding',
            [
                'label' => 'فاصله درونی',
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .header-cart-basket .cart-basket-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $settings['id'] = $this->get_id();

        $nav_args = array();

        $nav_args['style'] = $settings['style'];
        $nav_args['hover_align'] = $settings['bs_align'];
        ns_header_basket($nav_args);
    }

}
