<?php

namespace NegarshopElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

class Elementor_shop_product_categories extends \Elementor\Widget_Base
{

    public function get_name()
    {
        return 'negarshop_product_categories';
    }

    public function get_title()
    {
        return 'دسته بندی محصولات';
    }

    public function get_icon()
    {
        return 'eicon-product-categories';
    }

    public function get_categories()
    {
        return ['Negarshop_main'];
    }

    protected function _register_controls()
    {
        $this->start_controls_section('Content_settings', [
            'label' => 'محتوا',
            'tab' => Controls_Manager::TAB_CONTENT,
        ]);
        $this->add_control('displayStyle', [
            'label' => 'استایل نمایش',
            'type' => Controls_Manager::SELECT,
            'default' => 'list',
            'options' => [
                'list' => 'لیست',
                'vertical' => 'زیر هم',
            ],
        ]);

        $this->add_control('termsToShow', [
            'label' => 'نحوه نمایش',
            'type' => Controls_Manager::SELECT,
            'default' => 'latest',
            'options' => [
                'latest' => 'آخرین ها',
                'parents' => 'اصلی ها',
                'top' => 'تاپ ترین ها',
                'custom' => 'سفارشی',
            ],
        ]);

        $this->add_control('termsSelect', [
            'type' => 'query',
            'multiple' => true,
            'autocomplete' => [
                'object' => 'tax',
                'display' => 'detailed',
                'by_field' => 'term_taxonomy_id',
                'query' => [
                    'taxonomy' => 'product_cat'
                ],
            ],
            'condition' => [
                'termsToShow' => 'custom'
            ]
        ]);

        $this->add_control('termsCount', [
            'label' => 'تعداد',
            'type' => Controls_Manager::NUMBER,
            'min' => 1,
            'max' => 100,
            'step' => 1,
            'default' => 8
        ]);
        $this->add_control('countPerRow', [
            'label' => 'نمایش در هر سطر',
            'type' => Controls_Manager::SELECT,
            'default' => 'fill',
            'options' => [
                'fill' => 'همه در یک سطر',
                'auto' => 'خودکار',
                '1' => '1',
                '2' => '2',
                '3' => '3',
                '4' => '4',
                '6' => '6',
                '12' => '12',
            ],
        ]);
        $this->end_controls_section();


    }

    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $settings['id'] = $this->get_id();

        $termArgs = [
            'taxonomy' => 'product_cat',
            'hide_empty' => false,
            'number' => $settings['termsCount']
        ];

        if ($settings['termsToShow'] === 'latest') {
            $termArgs['orderby'] = 'id';
            $termArgs['order'] = 'DESC';
        }

        if ($settings['termsToShow'] === 'top') {
            $termArgs['orderby'] = 'count';
            $termArgs['order'] = 'DESC';
        }

        if ($settings['termsToShow'] === 'parents') {
            $termArgs['parent'] = 0;
            $termArgs['orderby'] = 'id';
            $termArgs['order'] = 'DESC';
        }

        if ($settings['termsToShow'] === 'custom' && !empty($settings['termsSelect'])) {
            $termArgs['include'] = $settings['termsSelect'];
        }

        $categories = get_terms($termArgs);

        if (empty($categories)) {
            return;
        }

        $colClass = "col-lg";
        if ($settings['countPerRow'] === 'auto') {
            $colClass .= '-auto';
        }
        if (is_numeric($settings['countPerRow'])) {
            $colClass .= '-' . (12 / $settings['countPerRow']);
        }
        $cardStyle = 'category-card--' . $settings['displayStyle'];

        echo '<div class="row">';
        foreach ($categories as $category) {
            $thumb = get_term_meta($category->term_id, 'thumbnail_id', true);
            printf('<div class="%s col-md-4 col-sm-6 mb-3">', $colClass);
            printf('<a href="%s" class="category-card %s">', get_term_link($category), $cardStyle);
            if (!empty($thumb) && $thumb !== false) {
                echo wp_get_attachment_image((int)$thumb, 'full');
            }
            echo '<div class="card-inner">';
            printf('<h4 class="card-title">%s</h4>', $category->name);
            printf('<div class="card-subtitle">' . __('+%s محصول', 'negarshop') . '</div>', $category->count);
            echo '</div>';
            echo '</a>';
            echo '</div>';
        }
        echo '</div>';
    }

}
